# Generated by dbt-depp init
{{ profile_name }}:
  target: dev
  outputs:
    dev:
      type: depp
      db_profile: dev_postgres
      database: {{ database }}
      schema: {{ schema }}

    dev_postgres:
      type: postgres
      host: {{ host }}
      port: {{ port }}
      user: {{ user }}
      password: {{ password }}
      database: {{ database }}
      schema: {{ schema }}
      threads: 4
